@@ -37,7 +37,7 @@ public class ArrayAny extends AwkUnaryArgs {
 	public AwkValue apply(AwkNamespace ns, AwkFiles o, AwkValue a1) {
 		if(a1.isArray()) {
 			for(AwkValue v : a1.values()) {
-				if(v.toBoolean())  return AwkInteger.TRUE;
+				if(v.toBoolean(ns))  return AwkInteger.TRUE;
 			}
 			return AwkInteger.FALSE;
 		}
