@@ -18,7 +18,7 @@ package net.morilib.awk.builtin.stat;
 import net.morilib.awk.builtin.AwkTernaryArgs;
 import net.morilib.awk.io.AwkFiles;
 import net.morilib.awk.namespace.AwkNamespace;
-import net.morilib.awk.stat.dist.continuous.BetaDistribution;
+import net.morilib.awk.stat.dist.BetaDistribution;
 import net.morilib.awk.value.AwkFloat;
 import net.morilib.awk.value.AwkValue;
 
