@@ -123,9 +123,9 @@ public class AwkArray extends AwkValue {
 		return true;
 	}
 
-	public boolean toBoolean() {
+	public boolean toBoolean(AwkNamespace ns) {
 		for(AwkValue v : values()) {
-			if(!v.toBoolean())  return false;
+			if(!v.toBoolean(ns))  return false;
 		}
 		return true;
 	}
