@@ -25,6 +25,11 @@ import net.morilib.awk.AwkArithmeticException;
 import net.morilib.awk.AwkCastException;
 import net.morilib.awk.namespace.AwkNamespace;
 
+/**
+ * awkium値の基底クラスです。
+ * 
+ * @author MORIGUCHI, Yuichiro 2013/03
+ */
 public abstract class AwkValue {
 
 	private static final BigInteger MINB =
@@ -33,23 +38,24 @@ public abstract class AwkValue {
 		BigInteger.valueOf(Integer.MAX_VALUE);
 
 	/**
-	 * 
+	 * 真の値です。
 	 */
 	public static final AwkValue TRUE = AwkInteger.valueOf(1);
 
 	/**
-	 * 
+	 * 偽の値です。
 	 */
 	public static final AwkValue FALSE = AwkInteger.valueOf(0);
 
 	/**
-	 * 
+	 * IOエラーの値です。
 	 */
 	public static final AwkValue IOERROR = AwkInteger.valueOf(-1);
 
 	/**
+	 * 整数に変換します。
 	 * 
-	 * @return
+	 * @return 整数
 	 */
 	public BigInteger toInteger() {
 //		throw new AwkCastException(this + " is not a number");
@@ -57,8 +63,11 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * int型の整数に変換します。<br />
+	 * int型であらわされないときは例外を返します。
 	 * 
-	 * @return
+	 * @return int型の整数
+	 * @throws AwkArithmeticException
 	 */
 	public int toIntExact() {
 		if(!isIntValue()) {
@@ -69,8 +78,9 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 浮動小数に変換します。
 	 * 
-	 * @return
+	 * @return 浮動小数
 	 */
 	public double toFloat() {
 //		throw new AwkCastException(this + " is not a number");
@@ -78,36 +88,42 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 文字列に変換します。
 	 * 
-	 * @return
+	 * @param ns 名前空間
+	 * @return 文字列
 	 */
 	public abstract String toString(AwkNamespace ns);
 
 	/**
+	 * 文字列に変換します。
 	 * 
-	 * @return
+	 * @return 文字列
 	 */
 	public String toString() {
 		return toString(null);
 	}
 
 	/**
+	 * booleanに変換します。
 	 * 
-	 * @return
+	 * @return 0のときfalse、そうでないときtrue
 	 */
-	public abstract boolean toBoolean();
+	public abstract boolean toBoolean(AwkNamespace ns);
 
 	/**
+	 * 実数に変換します。
 	 * 
-	 * @return
+	 * @return 実数
 	 */
 	public Number toReal() {
 		throw new AwkCastException(this + " is not a number");
 	}
 
 	/**
+	 * 正規表現に変換します。
 	 * 
-	 * @return
+	 * @return 正規表現
 	 */
 	public Pattern toRegex() {
 		throw new AwkCastException(
@@ -115,38 +131,46 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 配列に変換します。
 	 * 
-	 * @return
+	 * @return 配列
 	 */
 	public AwkArray toArray() {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * Javaオブジェクトに変換します。
 	 * 
-	 * @return
+	 * @return Javaオブジェクト
 	 */
 	public abstract Object toObject();
 
 	/**
+	 * 配列の値を参照します。
 	 * 
-	 * @return
+	 * @param v 添字
+	 * @return 配列の値
 	 */
 	public AwkValue referArray(String v) {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列の値をおきます。
 	 * 
-	 * @return
+	 * @param k 添字
+	 * @param v 値
+	 * @return 配列の前の値
 	 */
 	public AwkValue putArray(String k, AwkValue v) {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列の添字があるときtrueを得ます。
 	 * 
-	 * @param k
+	 * @param k 添字
 	 * @return
 	 */
 	public boolean contains(String k) {
@@ -154,86 +178,97 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 添字に相当する配列を削除します。
 	 * 
-	 * @return
+	 * @param v 添字
+	 * @return 配列の前の値
 	 */
 	public AwkValue deleteArray(String v) {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列の添字の集合を取得します。
 	 * 
-	 * @return
+	 * @return 添字の集合
 	 */
 	public Set<String> keys() {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列の値の集合を取得します。
 	 * 
-	 * @return
+	 * @return 値の集合
 	 */
 	public Collection<AwkValue> values() {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列の添字と値の集合を取得します。
 	 * 
-	 * @return
+	 * @return 添字と値の集合
 	 */
 	public Set<Map.Entry<String, AwkValue>> entrySet() {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列の添字と値のMapを取得します。
 	 * 
-	 * @return
+	 * @return 添字と値のMap
 	 */
 	public Map<String, AwkValue> map() {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
-	 * 
-	 * @return
+	 * 配列をクリアします。
 	 */
 	public void clear() {
 		throw new AwkCastException(this + " is not an array");
 	}
 
 	/**
+	 * 配列のサイズを得ます。
 	 * 
-	 * @return
+	 * @return サイズ
 	 */
 	public int size() {
 		return 1;
 	}
 
 	/**
+	 * 整数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isInteger();
 
 	/**
+	 * 浮動小数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isFloat();
 
 	/**
+	 * 実数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isReal();
 
 	/**
+	 * 型が整数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isIntegerValue();
 
 	/**
+	 * 型がint型整数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
@@ -244,42 +279,49 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 型が浮動小数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isFloatValue();
 
 	/**
+	 * 型が実数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isRealValue();
 
 	/**
+	 * 正数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isPositiveValue();
 
 	/**
+	 * 0のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isZeroValue();
 
 	/**
+	 * 負数のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isNegativeValue();
 
 	/**
+	 * 文字列のときtrueを得ます。
 	 * 
 	 * @return
 	 */
 	public abstract boolean isString();
 
 	/**
+	 * 正規表現のときtrueを得ます。
 	 * 
 	 * @return
 	 */
@@ -292,6 +334,7 @@ public abstract class AwkValue {
 	public abstract boolean isFunction();
 
 	/**
+	 * 空のときtrueを得ます。
 	 * 
 	 * @return
 	 */
@@ -300,6 +343,7 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 配列のときtrueを得ます。
 	 * 
 	 * @return
 	 */
@@ -308,25 +352,28 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 名前空間を得ます。
 	 * 
-	 * @return
+	 * @return 名前空間
 	 */
 	public AwkNamespace getNamespace() {
 		return null;
 	}
 
 	/**
+	 * 値を比較します。
 	 * 
-	 * @param v
-	 * @param ns
-	 * @return
+	 * @param v  比較する値
+	 * @param ns 名前空間
+	 * @return このオブジェクトが大きいときは1、小さいときは-1、等しいときは0
 	 */
 	public abstract int compareTo(AwkValue v, AwkNamespace ns);
 
 	/**
+	 * 文字列を可能ならば数値に変換します。
 	 * 
-	 * @param s
-	 * @return
+	 * @param s 文字列
+	 * @return 値
 	 */
 	public static AwkValue cast(String s) {
 		try {
@@ -341,10 +388,11 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値を足します。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @return 結果
 	 */
 	public static AwkValue add(AwkValue r1, AwkValue r2) {
 		AwkArray r0;
@@ -380,21 +428,22 @@ public abstract class AwkValue {
 				r0.putArray(s, add(r1, z.getValue()));
 			}
 			return r0;
-		} else if(r1.isFloat() || r2.isFloat()) {
-			return AwkFloat.valueOf(r1.toFloat() + r2.toFloat());
 		} else if(r1.isIntegerValue() && r2.isIntegerValue()) {
 			return AwkInteger.valueOf(
 					r1.toInteger().add(r2.toInteger()));
+		} else if(r1.isFloat() || r2.isFloat()) {
+			return AwkFloat.valueOf(r1.toFloat() + r2.toFloat());
 		} else {
 			return AwkFloat.valueOf(r1.toFloat() + r2.toFloat());
 		}
 	}
 
 	/**
+	 * 値を引きます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @return 結果
 	 */
 	public static AwkValue sub(AwkValue r1, AwkValue r2) {
 		AwkArray r0;
@@ -430,21 +479,22 @@ public abstract class AwkValue {
 				r0.putArray(s, sub(r1, z.getValue()));
 			}
 			return r0;
-		} else if(r1.isFloat() || r2.isFloat()) {
-			return AwkFloat.valueOf(r1.toFloat() - r2.toFloat());
 		} else if(r1.isIntegerValue() && r2.isIntegerValue()) {
 			return AwkInteger.valueOf(
 					r1.toInteger().subtract(r2.toInteger()));
+		} else if(r1.isFloat() || r2.isFloat()) {
+			return AwkFloat.valueOf(r1.toFloat() - r2.toFloat());
 		} else {
 			return AwkFloat.valueOf(r1.toFloat() - r2.toFloat());
 		}
 	}
 
 	/**
+	 * 値を掛けます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @return 結果
 	 */
 	public static AwkValue mul(AwkValue r1, AwkValue r2) {
 		AwkArray r0;
@@ -489,21 +539,22 @@ public abstract class AwkValue {
 				r0.putArray(s, mul(r1, z.getValue()));
 			}
 			return r0;
-		} else if(r1.isFloat() || r2.isFloat()) {
-			return AwkFloat.valueOf(r1.toFloat() * r2.toFloat());
 		} else if(r1.isIntegerValue() && r2.isIntegerValue()) {
 			return AwkInteger.valueOf(
 					r1.toInteger().multiply(r2.toInteger()));
+		} else if(r1.isFloat() || r2.isFloat()) {
+			return AwkFloat.valueOf(r1.toFloat() * r2.toFloat());
 		} else {
 			return AwkFloat.valueOf(r1.toFloat() * r2.toFloat());
 		}
 	}
 
 	/**
+	 * 値を割ります。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @return 結果
 	 */
 	public static AwkValue div(AwkValue r1, AwkValue r2) {
 		BigInteger e, f;
@@ -556,8 +607,6 @@ public abstract class AwkValue {
 				r0.putArray(s, div(r1, z.getValue()));
 			}
 			return r0;
-		} else if(r1.isFloat() || r2.isFloat()) {
-			return AwkFloat.valueOf(r1.toFloat() / r2.toFloat());
 		} else if(r1.isIntegerValue() && r2.isIntegerValue()) {
 			try {
 				e = r1.toInteger();
@@ -569,15 +618,18 @@ public abstract class AwkValue {
 			} catch(ArithmeticException z) {
 				throw new AwkArithmeticException(z.getMessage());
 			}
+		} else if(r1.isFloat() || r2.isFloat()) {
+			return AwkFloat.valueOf(r1.toFloat() / r2.toFloat());
 		}
 		return AwkFloat.valueOf(r1.toFloat() / r2.toFloat());
 	}
 
 	/**
+	 * 値のべき乗をとります。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @return 結果
 	 */
 	public static AwkValue pow(AwkValue r1, AwkValue r2) {
 		BigInteger f;
@@ -645,9 +697,10 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値の符号を変えます。
 	 * 
-	 * @param v
-	 * @return
+	 * @param v 値
+	 * @return 結果
 	 */
 	public static AwkValue neg(AwkValue v) {
 		AwkArray r0;
@@ -670,10 +723,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値を文字列連結します。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue concat(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -718,10 +773,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値が等しいかを調べます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue equals(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -757,7 +814,8 @@ public abstract class AwkValue {
 				s = z.getKey();
 				if(r1.contains(s)) {
 					x = equals(r1.referArray(s), z.getValue(), ns);
-					a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+					a.putArray(s, AwkInteger.booleanOf(
+							x.toBoolean(ns)));
 				} else {
 					a.putArray(s, AwkInteger.booleanOf(
 							z.getValue().isEmpty()));
@@ -777,7 +835,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r1.entrySet()) {
 				s = z.getKey();
 				x = equals(r1.referArray(s), r2, ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else if(r2.isArray()) {
@@ -785,7 +843,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r2.entrySet()) {
 				s = z.getKey();
 				x = equals(r1, r2.referArray(s), ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else {
@@ -794,10 +852,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値が等しくないかを調べます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue ne(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -833,7 +893,8 @@ public abstract class AwkValue {
 				s = z.getKey();
 				if(r1.contains(s)) {
 					x = ne(r1.referArray(s), z.getValue(), ns);
-					a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+					a.putArray(s, AwkInteger.booleanOf(
+							x.toBoolean(ns)));
 				} else {
 					a.putArray(s, AwkInteger.booleanOf(
 							!z.getValue().isEmpty()));
@@ -853,7 +914,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r1.entrySet()) {
 				s = z.getKey();
 				x = ne(r1.referArray(s), r2, ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else if(r2.isArray()) {
@@ -861,7 +922,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r2.entrySet()) {
 				s = z.getKey();
 				x = ne(r1, r2.referArray(s), ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else {
@@ -870,11 +931,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値が小さいかを調べます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @param ns
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue lt(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -892,7 +954,8 @@ public abstract class AwkValue {
 				s = z.getKey();
 				if(r1.contains(s)) {
 					x = lt(r1.referArray(s), z.getValue(), ns);
-					a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+					a.putArray(s, AwkInteger.booleanOf(
+							x.toBoolean(ns)));
 				} else {
 					a.putArray(s, AwkInteger.booleanOf(
 							z.getValue().isPositiveValue()));
@@ -912,7 +975,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r1.entrySet()) {
 				s = z.getKey();
 				x = lt(r1.referArray(s), r2, ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else if(r2.isArray()) {
@@ -920,7 +983,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r2.entrySet()) {
 				s = z.getKey();
 				x = lt(r1, r2.referArray(s), ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else {
@@ -929,11 +992,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値が大きくないかを調べます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @param ns
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue le(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -951,7 +1015,8 @@ public abstract class AwkValue {
 				s = z.getKey();
 				if(r1.contains(s)) {
 					x = le(r1.referArray(s), z.getValue(), ns);
-					a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+					a.putArray(s, AwkInteger.booleanOf(
+							x.toBoolean(ns)));
 				} else {
 					a.putArray(s, AwkInteger.booleanOf(
 							!z.getValue().isNegativeValue()));
@@ -971,7 +1036,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r1.entrySet()) {
 				s = z.getKey();
 				x = le(r1.referArray(s), r2, ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else if(r2.isArray()) {
@@ -979,7 +1044,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r2.entrySet()) {
 				s = z.getKey();
 				x = le(r1, r2.referArray(s), ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else {
@@ -988,11 +1053,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値が大きいかを調べます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @param ns
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue gt(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -1010,7 +1076,8 @@ public abstract class AwkValue {
 				s = z.getKey();
 				if(r1.contains(s)) {
 					x = gt(r1.referArray(s), z.getValue(), ns);
-					a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+					a.putArray(s, AwkInteger.booleanOf(
+							x.toBoolean(ns)));
 				} else {
 					a.putArray(s, AwkInteger.booleanOf(
 							z.getValue().isNegativeValue()));
@@ -1030,7 +1097,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r1.entrySet()) {
 				s = z.getKey();
 				x = gt(r1.referArray(s), r2, ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else if(r2.isArray()) {
@@ -1038,7 +1105,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r2.entrySet()) {
 				s = z.getKey();
 				x = gt(r1, r2.referArray(s), ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else {
@@ -1047,11 +1114,12 @@ public abstract class AwkValue {
 	}
 
 	/**
+	 * 値が小さくないかを調べます。
 	 * 
-	 * @param r1
-	 * @param r2
-	 * @param ns
-	 * @return
+	 * @param r1 値
+	 * @param r2 値
+	 * @param ns 名前空間
+	 * @return 結果
 	 */
 	public static AwkValue ge(AwkValue r1, AwkValue r2,
 			AwkNamespace ns) {
@@ -1069,7 +1137,8 @@ public abstract class AwkValue {
 				s = z.getKey();
 				if(r1.contains(s)) {
 					x = ge(r1.referArray(s), z.getValue(), ns);
-					a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+					a.putArray(s, AwkInteger.booleanOf(
+							x.toBoolean(ns)));
 				} else {
 					a.putArray(s, AwkInteger.booleanOf(
 							!z.getValue().isPositiveValue()));
@@ -1089,7 +1158,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r1.entrySet()) {
 				s = z.getKey();
 				x = ge(r1.referArray(s), r2, ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else if(r2.isArray()) {
@@ -1097,7 +1166,7 @@ public abstract class AwkValue {
 			for(Map.Entry<String, AwkValue> z : r2.entrySet()) {
 				s = z.getKey();
 				x = ge(r1, r2.referArray(s), ns);
-				a.putArray(s, AwkInteger.booleanOf(x.toBoolean()));
+				a.putArray(s, AwkInteger.booleanOf(x.toBoolean(ns)));
 			}
 			return a;
 		} else {
